@@ -12,7 +12,7 @@ cat(str)
 
 
 ###################################################
-### code chunk number 2: variable_interpolation.Rnw:42-46
+### code chunk number 2: variable_interpolation.Rnw:43-47
 ###################################################
 library(GetoptLong)
 
@@ -21,13 +21,13 @@ cat(str)
 
 
 ###################################################
-### code chunk number 3: variable_interpolation.Rnw:51-52
+### code chunk number 3: variable_interpolation.Rnw:52-53
 ###################################################
 qqcat("region = (@{region[1]}, @{region[2]}), value = @{value}, name = '@{name}'")
 
 
 ###################################################
-### code chunk number 4: variable_interpolation.Rnw:58-66
+### code chunk number 4: variable_interpolation.Rnw:59-67
 ###################################################
 options("cat_prefix" = "[INFO] ")
 qqcat("This is a message")
@@ -40,20 +40,35 @@ qqcat("This is a message")
 
 
 ###################################################
-### code chunk number 5: variable_interpolation.Rnw:71-73
+### code chunk number 5: variable_interpolation.Rnw:72-74
 ###################################################
 options("cat_prefix" = "[INFO] ", "cat_verbose" = FALSE)
 qqcat("This is a message")
 
 
 ###################################################
-### code chunk number 6: variable_interpolation.Rnw:76-77
+### code chunk number 6: variable_interpolation.Rnw:77-78
 ###################################################
 options("cat_prefix" = NULL)
 
 
 ###################################################
-### code chunk number 7: variable_interpolation.Rnw:83-88 (eval = FALSE)
+### code chunk number 7: variable_interpolation.Rnw:82-86
+###################################################
+options("cat_verbose" = NULL)
+options("cat_prefix" = "[DEBUG] ")
+qqcat("This is a message", cat_prefix = "[INFO] ")
+qqcat("This is a message")
+
+
+###################################################
+### code chunk number 8: variable_interpolation.Rnw:89-90
+###################################################
+options("cat_prefix" = NULL)
+
+
+###################################################
+### code chunk number 9: variable_interpolation.Rnw:96-101 (eval = FALSE)
 ###################################################
 ## GetoptLongc(
 ##     "verbose", "Print message"
@@ -63,13 +78,13 @@ options("cat_prefix" = NULL)
 
 
 ###################################################
-### code chunk number 8: variable_interpolation.Rnw:91-92
+### code chunk number 10: variable_interpolation.Rnw:104-105
 ###################################################
 options("cat_verbose" = NULL)
 
 
 ###################################################
-### code chunk number 9: variable_interpolation.Rnw:97-101
+### code chunk number 11: variable_interpolation.Rnw:110-114
 ###################################################
 n = 1
 qqcat("There @{ifelse(n == 1, 'is', 'are')} @{n} dog@{ifelse(n == 1, '', 's')}.\n")
@@ -78,26 +93,26 @@ qqcat("There @{ifelse(n == 1, 'is', 'are')} @{n} dog@{ifelse(n == 1, '', 's')}.\
 
 
 ###################################################
-### code chunk number 10: variable_interpolation.Rnw:108-109 (eval = FALSE)
+### code chunk number 12: variable_interpolation.Rnw:121-122 (eval = FALSE)
 ###################################################
 ## qq = GetoptLong::qq
 
 
 ###################################################
-### code chunk number 11: variable_interpolation.Rnw:121-123
+### code chunk number 13: variable_interpolation.Rnw:134-136
 ###################################################
 x = 1
 qqcat("x = #{x}", code.pattern = "#\\{CODE\\}")
 
 
 ###################################################
-### code chunk number 12: variable_interpolation.Rnw:128-129 (eval = FALSE)
+### code chunk number 14: variable_interpolation.Rnw:141-142 (eval = FALSE)
 ###################################################
 ## options("code.pattern" = "#\\{CODE\\}")
 
 
 ###################################################
-### code chunk number 13: variable_interpolation.Rnw:136-149 (eval = FALSE)
+### code chunk number 15: variable_interpolation.Rnw:149-162 (eval = FALSE)
 ###################################################
 ## code.pattern = "@\\{CODE\\}"    # default style
 ## code.pattern = "@\\[CODE\\]"
@@ -115,13 +130,13 @@ qqcat("x = #{x}", code.pattern = "#\\{CODE\\}")
 
 
 ###################################################
-### code chunk number 14: variable_interpolation.Rnw:160-161 (eval = FALSE)
+### code chunk number 16: variable_interpolation.Rnw:173-174 (eval = FALSE)
 ###################################################
 ## code.pattern = "`CODE`"
 
 
 ###################################################
-### code chunk number 15: variable_interpolation.Rnw:169-172
+### code chunk number 17: variable_interpolation.Rnw:182-185
 ###################################################
 x = 1
 y = 2
@@ -129,7 +144,7 @@ qqcat("x = @{x}, y = @{y}", envir = list(x = "a", y = "b"))
 
 
 ###################################################
-### code chunk number 16: variable_interpolation.Rnw:182-189
+### code chunk number 18: variable_interpolation.Rnw:195-202
 ###################################################
 x = 1:6
 qqcat("@{x} is an @{ifelse(x %% 2, 'odd', 'even')} number.\n")
@@ -141,7 +156,7 @@ qqcat("@{x}, @{y}, @{z}\n")
 
 
 ###################################################
-### code chunk number 17: variable_interpolation.Rnw:194-197
+### code chunk number 19: variable_interpolation.Rnw:207-210
 ###################################################
 name = letters[1:4]
 value = 1:4
@@ -149,15 +164,26 @@ qqcat("<tr><td>@{name}</td><td>@{value}</td><tr>\n")
 
 
 ###################################################
-### code chunk number 18: variable_interpolation.Rnw:209-220
+### code chunk number 20: variable_interpolation.Rnw:214-217
+###################################################
+str = qq("@{x}, @{y}, @{z}", collapse = FALSE)
+length(str)
+str
+
+
+###################################################
+### code chunk number 21: variable_interpolation.Rnw:228-242
 ###################################################
 name = letters[1:4]
 value = 1:4
 str = qq("`
   text = character(length(name))
   for(i in seq_along(name)) {
-    class = ifelse(i %% 2, 'odd', 'even')
-      text[i] = qq(\"<tr class='@{class}'><td>@{name[i]}</td><td>@{value[i]}</td></tr>\n\")
+    if(i == 1) {
+      text[i] = qq(\"<tr class='highlight'><td>@{name[i]}</td><td>@{value[i]}</td></tr>\n\")
+    } else {
+      text[i] = qq(\"<tr><td>@{name[i]}</td><td>@{value[i]}</td></tr>\n\")
+    }
   }
 text
 `", code.pattern = "`CODE`")
@@ -165,20 +191,16 @@ cat(str)
 
 
 ###################################################
-### code chunk number 19: variable_interpolation.Rnw:231-249
+### code chunk number 22: variable_interpolation.Rnw:253-267
 ###################################################
 html = "<html>
 <body>
 <h2>Report for [% report_name %]</h2>
 <table>
-	<tr><th>name</th><th>value</th></tr>
+<tr><th>name</th><th>value</th></tr>
 [% 
-text = character(length(name))
-for(i in seq_along(name)) {
-  class = ifelse(i %% 2, 'odd', 'even')
-    text[i] = qq(\"<tr class='@{class}'><td>@{name[i]}</td><td>@{value[i]}</td></tr>\\n\")
-}
-paste(text, collapse = '')  # make sure this chunk only returns vector with length of 1.
+i = seq_along(name)
+qq(\"<tr@{ifelse(i == 1, ' class=\\\"highlight\\\"', '')}><td>@{name}</td><td>@{value}</td></tr>\n\")
 %]
 </table>
 </body>
@@ -188,7 +210,7 @@ cat(html)
 
 
 ###################################################
-### code chunk number 20: variable_interpolation.Rnw:256-263 (eval = FALSE)
+### code chunk number 23: variable_interpolation.Rnw:271-278 (eval = FALSE)
 ###################################################
 ## template = paste(readLines("template.html"), collapse = "\n")
 ## 
@@ -200,7 +222,7 @@ cat(html)
 
 
 ###################################################
-### code chunk number 21: variable_interpolation.Rnw:268-272
+### code chunk number 24: variable_interpolation.Rnw:283-287
 ###################################################
 report_name = "test"
 name = letters[1:4]
